from __future__ import absolute_import, unicode_literals

# Below: Journals with really annoying paywalls guarding their precious
# secrets.
schattauer_journals = [
    'Thromb Haemost',
]

# Royal Society of Chemistry
RSC_journals = ['Nat Prod Rep']

# thieme journals so far don't seem to have any open access content.
# example links to article page: https://www.thieme-connect.com/DOI/DOI?10.1055/s-0028-1085467
#           https://www.thieme-connect.com/DOI/DOI?10.1055/s-2007-1004566
thieme_journals = ['Neuropediatrics', 'Semin Vasc Med', 'Exp Clin Endocrinol Diabetes',
                   'Int J Sports Med', 'Horm Metab Res', 'Drug Res (Stuttg)',
                   ]

weird_paywall_publishers = ['J Ment Health Policy Econ']
