from __future__ import absolute_import, unicode_literals

wiley_journals = [
        'APMIS',
        'Acad Emerg Med',
        'Acta Anaesthesiol Scand',
        'Acta Crystallogr C',
        'Acta Neurol Scand',
        'Acta Neurol Scand Supplc',
        'Acta Neuropsychiatr',
        'Acta Obstet Gynecol Scand',
        'Acta Obstet Gynecol Scand Suppl',
        'Acta Ophthalmol',
        'Acta Ophthalmol (Copenh)',
        'Acta Ophthalmol Scand',
        'Acta Ophthalmol Scand Suppl',
        'Acta Paediatr',
        'Acta Paediatr Jpn',
        'Acta Paediatr Scand',
        'Acta Paediatr Suppl',
        'Acta Pathol Jpn',
        'Acta Pathol Microbiol Scand B',
        'Acta Physiol (Oxf)',
        'Acta Physiol Scand',
        'Acta Psychiatr Scand',
        'Addict Biol',
        'Addiction',
        'Aging Cell',
        'Alcohol Clin Exp Res',
        'Aliment Pharmacol Ther',
        'Allergy',
        'Am J Addict',
        'Am J Anat',
        'Am J Hematol',
        'Am J Hum Biol',
        'Am J Ind Med',
        'Am J Med Genet',
        'Am J Med Genet A',
        'Am J Med Genet B Neuropsychiatr Genet',
        'Am J Med Genet C Semin Med Genet',
        'Am J Phys Anthropol',
        'Am J Primatol',
        'Am J Reprod Immunol',
        'Am J Transplant',
        'Anaesthesia',
        'Anat Histol Embryol',
        'Anat Rec',
        'Anat Rec (Hoboken)',
        'Andrologia',
        'Andrology',
        'Angew Chem Int Ed Engl',
        'Anim Genet',
        'Anim Sci J',
        'Ann Biol Clin (Paris)',
        'Ann Endocrinol (Paris)',
        'Ann Hum Genet',
        'Ann N Y Acad Sci',
        'Ann Neurol',
        'Ann Noninvasive Electrocardiol',
        'Antivir Ther (Lond)',
        'Arch Insect Biochem Physiol',
        'Arch Mal Coeur Vaiss',
        'Arch Pharm (Weinheim)',
        'Arthritis & rheumatology (Hoboken NJ)',
        'Arthritis Care Res (Hoboken)',
        'Arthritis Rheum',
        'Artif Organs',
        'Asia Pac J Clin Oncol',
        'Asia Pac Psychiatry',
        'Aust Dent J',
        'Aust Endod J',
        'Aust N Z J Obstet Gynaecol',
        'Aust Vet J',
        'Australas J Dermatol',
        'Autism Res',
        'BJOG',
        'BJU Int',
        'Basic Clin Pharmacol Toxicol',
        'Biochem Mol Biol Educ',
        'Biochem Mol Biol Int',
        'Bioelectromagnetics',
        'Bioessays',
        'Biofactors',
        'Biol Cell',
        'Biol Rev Camb Philos Soc',
        'Biom J',
        'Biomed Biochim Acta',
        'Biomed Chromatogr',
        'Bioorg Med Chem Lett',
        'Biopharm Drug Dispos',
        'Biopolymers',
        'Biotechnol Appl Biochem',
        'Biotechnol Bioeng',
        'Biotechnol J',
        'Biotechnol Prog',
        'Bipolar Disord',
        'Birth Defects Res A Clin Mol Teratol',
        'Birth Defects Res C Embryo Today',
        'Birth Defects Res Part A Clin Mol Teratol',
        'Br J Clin Pharmacol',
        'Br J Dermatol',
        'Br J Haematol',
        'Br J Surg',
        'Brain Pathol',
        'Breast J',
        'CNS Neurosci Ther',
        'Cancer',
        'Cancer Cytopathol',
        'Cancer Med',
        'Cancer Sci',
        'Cardiovasc Drug Rev',
        'Cardiovasc Ther',
        'Cas Lek Cesk',
        'Cathet Cardiovasc Diagn',
        'Catheter Cardiovasc Interv',
        'Cell Biochem Funct',
        'Cell Biol Int',
        'Cell Microbiol',
        'Cell Mol Biol (Noisy-le-grand)',
        'Cell Motil Cytoskeleton',
        'Cell Prolif',
        'Cell Tissue Kinet',
        'Chem Asian J',
        'Chem Biodivers',
        'Chem Biol Drug Des',
        'Chem Pharm Bull',
        'Chem Rec',
        'ChemMedChem',
        'ChemSusChem',
        'Chembiochem',
        'Chemistry',
        'Chemphyschem',
        'Child Dev',
        'Chirality',
        'Clin Cardiol',
        'Clin Endocrinol (Oxf)',
        'Clin Exp Allergy',
        'Clin Exp Dermatol',
        'Clin Exp Pharmacol Physiol',
        'Clin Exp Pharmacol Physiol Suppl',
        'Clin Experiment Ophthalmol',
        'Clin Genet',
        'Clin Lab Haematol',
        'Clin Oral Implants Res',
        'Clin Otolaryngol Allied Sci',
        'Clin Pharmacol Ther',
        'Clin Physiol',
        'Clin Physiol Funct Imaging',
        'Clin Respir J',
        'Clin Transl Sci',
        'Clin Transplant',
        'Cochrane Database Syst Rev',
        'Colorectal Dis',
        'Compr Physiol', 
        'Congenit Anom (Kyoto)',
        'Congenit Heart Dis',
        'Congest Heart Fail',
        'Contact Derm',
        'Contrast Media Mol Imaging',
        'Cytometry',
        'Cytometry A',
        'Cytometry B Clin Cytom',
        'Cytopathology',
        'Depress Anxiety',
        'Dermatol Ther',
        'Dev Dyn',
        'Dev Genet',
        'Dev Growth Differ',
        'Dev Med Child Neurol',
        'Dev Neurobiol',
        'Diabet Med',
        'Diabetes Metab Res Rev',
        'Diabetes Obes Metab',
        'Diagn Cytopathol',
        'Differentiation',
        'Dig Endosc',
        'Dis Esophagus',
        'Drug Test Anal',
        'EDTNA ERCA J',
        'Electrophoresis',
        'Emerg Med Australas',
        'Endod Dent Traumatol',
        'Environ Microbiol',
        'Environ Microbiol Rep',
        'Environ Mol Mutagen',
        'Environ Mutagen',
        'Environ Toxicol',
        'Environ Toxicol Chem',
        'Epilepsia',
        'Equine Vet J',
        'Equine Vet J Suppl',
        'Eur Eat Disord Rev',
        'Eur J Biochem',
        'Eur J Clin Invest',
        'Eur J Dermatol',
        'Eur J Gynaecol Oncol',
        'Eur J Haematol',
        'Eur J Haematol Suppl',
        'Eur J Heart Fail',
        'Eur J Immunogenet',
        'Eur J Immunol',
        'Eur J Neurol',
        'Eur J Neurosci',
        'Eur J Oral Sci',
        'Eur J Pain',
        'Evolution',
        'Exp Dermatol',
        'Exp Physiol',
        'FEBS J',
        'Farmaco',
        'Fundam Clin Pharmacol',
        'Genes Brain Behav',
        'Genes Cells',
        'Genes Chromosomes Cancer',
        'Genesis',
        'Genet Epidemiol',
        'Geobiology',
        'Geriatr Gerontol Int',
        'Gerodontology',
        'Glia',
        'HIV Med',
        'Haemophilia',
        'Head Neck',
        'Headache',
        'Helicobacter',
        'Hematol Oncol',
        'Hemodial Int',
        'Hepatology',
        'Hereditas',
        'Hippocampus',
        'Histopathology',
        'Hum Brain Mapp',
        'Hum Mutat',
        'Hum Psychopharmacol',
        'IUBMB Life',
        'Immunol Rev',
        'Influenza Other Respir Viruses',
        'Insect Mol Biol',
        'Insect Sci',
        'Int Arch Allergy Appl Immunol',
        'Int Dent J',
        'Int Endod J',
        'Int Forum Allergy Rhinol',
        'Int J Androl',
        'Int J Cancer',
        'Int J Clin Pract',
        'Int J Dermatol',
        'Int J Eat Disord',
        'Int J Geriatr Psychiatry',
        'Int J Gynecol Cancer',
        'Int J Immunogenet',
        'Int J Lab Hematol',
        'Int J Lang Commun Disord',
        'Int J Med Robot',
        'Int J Paediatr Dent',
        'Int J Pept Protein Res',
        'Int J Protein Res',
        'Int J Rheum Dis',
        'Int J Stroke',
        'Int J Urol',
        'Intern Med J',
        'J Am Assoc Nurse Pract',
        'J Am Geriatr Soc',
        'J Anat',
        'J Androl',
        'J Anim Breed Genet',
        'J Appl Bacteriol',
        'J Appl Microbiol',
        'J Appl Toxicol',
        'J Basic Microbiol',
        'J Biochem Mol Toxicol',
        'J Biolumin Chemilumin',
        'J Biomed Mater Res',
        'J Biomed Mater Res A',
        'J Biomed Mater Res Part B Appl Biomater',
        'J Bone Miner Res',
        'J Cardiometab Syndr',
        'J Cardiovasc Electrophysiol',
        'J Cell Biochem',
        'J Cell Biochem Suppl',
        'J Cell Mol Med',
        'J Cell Physiol',
        'J Chem Technol Biotechnol',
        'J Child Psychol Psychiatry',
        'J Clin Apher',
        'J Clin Hypertens (Greenwich)',
        'J Clin Lab Anal',
        'J Clin Periodontol',
        'J Clin Pharm Ther',
        'J Clin Pharmacol',
        'J Clin Psychol',
        'J Comp Neurol',
        'J Comput Chem',
        'J Cutan Pathol',
        'J Dermatol',
        'J Diabetes',
        'J Dig Dis',
        'J Dtsch Dermatol Ges',
        'J Eukaryot Microbiol',
        'J Eur Acad Dermatol Venereol',
        'J Evid Based Med',
        'J Exp Anal Behav',
        'J Exp Zool',
        'J Exp Zool A Ecol Genet Physiol',
        'J Exp Zool B Mol Dev Evol',
        'J Exp Zoolog Part A Comp Exp Biol',
        'J Fish Biol',
        'J Fish Dis',
        'J Food Sci',
        'J Forensic Sci',
        'J Formos Med Assoc',
        'J Gastroenterol Hepatol',
        'J Gene Med',
        'J Hepatobiliary Pancreat Sci',
        'J Hosp Med',
        'J Hum Nutr Diet',
        'J Immunogenet',
        'J Integr Plant Biol',
        'J Intellect Disabil Res',
        'J Intern Med',
        'J Lab Clin Med',
        'J Magn Reson Imaging',
        'J Mass Spectrom',
        'J Matern Fetal Med',
        'J Med Imaging Radiat Oncol',
        'J Med Primatol',
        'J Med Virol',
        'J Microsc',
        'J Mol Recognit',
        'J Morphol',
        'J Nanosci Nanotechnol',
        'J Neurobiol',
        'J Neurochem',
        'J Neuroendocrinol',
        'J Neurosci Res',
        'J New Drugs',
        'J Obstet Gynaecol Res',
        'J Oral Pathol Med',
        'J Oral Rehabil',
        'J Org Chem',
        'J Orthop Res',
        'J Paediatr Child Health',
        'J Pathol',
        'J Pept Res',
        'J Pept Sci',
        'J Periodont Res',
        'J Peripher Nerv Syst',
        'J Pharm Pharmacol',
        'J Pharm Sci',
        'J Physiol',
        'J Pineal Res',
        'J Prosthodont',
        'J Rural Health',
        'J Sch Health',
        'J Sci Food Agric',
        'J Sep Sci',
        'J Sex Med',
        'J Sleep Res',
        'J Small Anim Pract',
        'J Supramol Struct',
        'J Surg Oncol',
        'J Thromb Haemost',
        'J Tissue Eng Regen Med',
        'J Trauma Stress',
        'J Vet Emerg Crit Care (San Antonio)',
        'J Vet Intern Med',
        'J Vet Med A Physiol Pathol Clin Med',
        'J Vet Med B Infect Dis Vet Public Health',
        'J Vet Pharmacol Ther',
        'J Viral Hepat',
        'Jpn J Cancer Res',
        'Laryngoscope',
        'Lasers Surg Med',
        'Lett Appl Microbiol',
        'Liver',
        'Liver Int',
        'Liver Transpl',
        'Luminescence',
        'Macromol Biosci',
        'Macromol Rapid Commun',
        'Magn Reson Chem',
        'Magn Reson Med',
        'Med Educ',
        'Med Pediatr Oncol',
        'Med Res Rev',
        'Med Vet Entomol',
        'Ment Retard Dev Disabil Res Rev',
        'Microbiol Immunol',
        'Microcirculation',
        'Microsc Res Tech',
        'Mikrobiyol Bul',
        'Mol Carcinog',
        'Mol Ecol',
        'Mol Ecol Resour',
        'Mol Microbiol',
        'Mol Nutr Food Res',
        'Mol Oral Microbiol',
        'Mol Plant Pathol',
        'Mol Reprod Dev',
        'Mov Disord',
        'Mt Sinai J Med',
        'Muscle Nerve',
        'Muscle Nerve Suppl',
        'Mycoses',
        'NMR Biomed',
        'Nan Fang Yi Ke Da Xue Xue Bao',
        'Nat Toxins',
        'Nephrology (Carlton)',
        'Neurochem Res',
        'Neurogastroenterol Motil',
        'Neuropathol Appl Neurobiol',
        'Neuropathology',
        'Neurourol Urodyn',
        'New Phytol',
        'Nihon Shokakibyo Gakkai Zasshi',
        'Nippon Rinsho',
        'Novartis Found Symp',
        'Nutr Clin Care',
        'Obes Res',
        'Obes Rev',
        'Obesity (Silver Spring)',
        'Ophthalmic Physiol Opt',
        'Opt Express',
        'Oral Dis',
        'Oral Microbiol Immunol',
        'Orthod Craniofac Res',
        'Orthop Surg',
        'Otolaryngol Head Neck Surg',
        'Pacing Clin Electrophysiol',
        'Paediatr Anaesth',
        'Paediatr Perinat Epidemiol',
        'Pain Med',
        'Pathol Int',
        'Pediatr Allergy Immunol',
        'Pediatr Blood Cancer',
        'Pediatr Dermatol',
        'Pediatr Diabetes',
        'Pediatr Int',
        'Pediatr Obes',
        'Pediatr Transplant',
        'Pest Manag Sci',
        'Pharmacoepidemiol Drug Saf',
        'Pharmacol Toxicol',
        'Pharmacotherapy',
        'Pharmazie',
        'Photochem Photobiol',
        'Photodermatol Photoimmunol Photomed',
        'Physiol Plant',
        'Phytochem Anal',
        'Phytother Res',
        'Pigment Cell Melanoma Res',
        'Pigment Cell Res',
        'Plant Biol (Stuttg)',
        'Plant Biotechnol J',
        'Plant Cell Environ',
        'Plant J',
        'Prenat Diagn',
        'Proc Assoc Am Physicians',
        'Prostate',
        'Protein Sci',
        'Proteins',
        'Proteomics',
        'Proteomics Clin Appl',
        'Psychiatry Clin Neurosci',
        'Psychogeriatrics',
        'Psychophysiology',
        'Public Health Nurs',
        'Rapid Commun Mass Spectrom',
        'Recenti Prog Med',
        'Reprod Domest Anim',
        'Respirology',
        'Rev Med Virol',
        'Scand J Haematol',
        'Scand J Immunol',
        'Scand J Med Sci Sports',
        'Skin Res Technol',
        'Small',
        'Stat Med',
        'Stem Cells',
        'Synapse',
        'Teratog Carcinog Mutagen',
        'Teratology',
        'Ther Apher Dial',
        'Tissue Antigens',
        'Traffic',
        'Transbound Emerg Dis',
        'Transfus Med',
        'Transfusion',
        'Transpl Infect Dis',
        'Transpl Int',
        'Trop Med Int Health',
        'Ugeskr Laeg',
        'Ultrasound Obstet Gynecol',
        'Verh Dtsch Ges Pathol',
        'Vet Anaesth Analg',
        'Vet Clin Pathol',
        'Vet Dermatol',
        'Vet Ophthalmol',
        'Vet Surg',
        'Vox Sang',
        'Wiad Lek',
        'Wiley Interdiscip Rev RNA',
        'Wound Repair Regen',
        'Xenotransplantation',
        'Yakugaku Zasshi',
        'Yeast',
        'Yi Chuan Xue Bao',
        'Z Allg Mikrobiol',
        'Z Tierpsychol',
        'Zentralbl Veterinarmed A',
        'Zentralblatt Veterinarmedizin Reihe B',
        'Zh Nevrol Psikhiatr Im S S Korsakova',
        'Zhongguo Dang Dai Er Ke Za Zhi',
        'Zhongguo Shi Yan Xue Ye Xue Za Zhi',
        'Zhongguo Yi Xue Ke Xue Yuan Xue Bao',
        'Zhonghua Bing Li Xue Za Zhi',
        'Zhonghua Er Ke Za Zhi',
        'Zhonghua Kou Qiang Yi Xue Za Zhi',
        'Zhonghua Yan Ke Za Zhi',
        'Zoonoses Public Health',
]
