from __future__ import absolute_import, unicode_literals

simple_formats_pii = {
    'Am Heart J': 'http://www.ahjonline.com/article/{a.pii}/pdf',
    'Am J Cardiol': 'http://www.ajconline.org/article/{a.pii}/pdf',
    'Am J Ophthalmol': 'http://www.ajo.com/article/{a.pii}/pdf',
    'Am J Med': 'http://www.amjmed.com/article/{a.pii}/pdf',
    'Atherosclerosis': 'http://www.atherosclerosis-journal.com/article/{a.pii}/pdf',
    'Arch Med Res': 'http://www.arcmedres.com/article/{a.pii}/pdf',
    'Biol Psychiatry': 'http://www.biologicalpsychiatryjournal.com/article/{a.pii}/pdf',
    'Bone': 'http://www.thebonejournal.com/article/{a.pii}/pdf',
    'Brain Dev': 'http://www.brainanddevelopment.com/article/{a.pii}/pdf',
    'Cancer Cell Int': 'http://www.cancerci.com/content/pdf/{a.pii}.pdf',
    'Cancer Genet Cytogenet': 'http://www.cancergeneticsjournal.org/article/{a.pii}/pdf',
    'Cancer Lett': 'http://www.cancerletters.info/article/{a.pii}/pdf',
    'Clin Neurol Neurosurg': 'http://www.clineu-journal.com/article/{a.pii}/pdf',
    'Diabetes Res Clin Pract': 'http://www.diabetesresearchclinicalpractice.com/article/{a.pii}/pdf',
    'Epilepsy Res': 'http://www.epires-journal.com/article/{a.pii}/pdf',
    'Eur J Paediatr Neurol': 'http://www.ejpn-journal.com/article/{a.pii}/pdf',
    'Exp Hematol': 'http://www.exphem.org/article/{a.pii}/pdf',
    'Fertil Steril': 'http://www.fertstert.org/article/{a.pii}/pdf',
    'Gastroenterology': 'http://www.gastrojournal.org/article/{a.pii}/pdf',
    'Gynecol Oncol': 'http://www.gynecologiconcology-online.net/article/{a.pii}/pdf',
    'Heart Rhythm': 'http://www.heartrhythmjournal.com/article/{a.pii}/pdf',
    'Int J Pediatr Otorhinolaryngol': 'http://www.ijporlonline.com/article/{a.pii}/pdf',
    'Int J Cardiol': 'http://www.internationaljournalofcardiology.com/article/{a.pii}/pdf',
    'J Dermatol': 'http://www.jdsjournal.com/article/{a.pii}/pdf',
    'J Mol Cell Cardiol': 'http://www.jmmc-online.com/article/{a.pii}/pdf',
    'J Mol Diagn': 'http://jmd.amjpathol.org/article/{a.pii}/pdf',
    'J Neurol Sci': 'http://www.jns-journal.com/article/{a.pii}/pdf',
    'J Pediatr': 'http://www.jpeds.com/article/{a.pii}/pdf',
    'J Pediatr Urol': 'http://www.jpurol.com/article/{a.pii}/pdf',
    'Ophthalmology': 'http://www.aaojournal.org/article/{a.pii}/pdf',
    'Orv Hetil': 'http://www.akademiai.com/content/{a.pii}/fulltext.pdf',
    'Med Hypotheses': 'http://www.medical-hypotheses.com/article/{a.pii}/pdf',
    'Metabolism': 'http://www.metabolismjournal.com/article/{a.pii}/pdf',
    'Metab Clin Exp': 'http://www.metabolismjournal.com/article/{a.pii}/pdf',
    'Mol Genet Metab': 'http://www.mgmjournal.com/article/{a.pii}/pdf',
    'Neurobiol Aging': 'http://www.neurobiologyofaging.org/article/{a.pii}/pdf',
    'Neuromuscul Disord': 'http://www.nmd-journal.com/article/{a.pii}/pdf',
    'Parkinsonism Relat Disord': 'http://www.prd-journal.com/article/{a.pii}/pdf',
    'Pediatr Neurol': 'http://www.pedneur.com/article/{a.pii}/pdf',
    'Placenta': 'http://www.placentajournal.org/article/{a.pii}/pdf',
    'Surg Neurol': 'http://www.worldneurosurgery.org/article/{a.pii}/pdf',
    'Thromb Res': 'http://www.thrombosisresearch.com/article/{a.pii}/pdf',
}
