from __future__ import absolute_import, unicode_literals

# JSTAGE: mostly free (yay)
# Examples:
# J Biochem: https://www.jstage.jst.go.jp/article/biochemistry1922/125/4/125_4_803/_pdf
# Drug Metab Pharmacokinet:
# https://www.jstage.jst.go.jp/article/dmpk/20/2/20_2_144/_article -->
# https://www.jstage.jst.go.jp/article/dmpk/20/2/20_2_144/_pdf
jstage_journals = [
        'Agric Biol Chem',
        'Anal Sci',
        'Ann Thorac Cardiovasc Surg',
        'Biol Pharm Bull',
        'Biomed Res',
        'Biosci Trends',
        'Cell Struct Funct',
        'Chem Pharm Bull',
        'Circ J',
        'Crit Rev Immunol',
        'Dent Mater J',
        'Drug Metab Pharmacokinet',
        'Endocr J',
        'Exp Anim',
        'Fukushima J Med Sci',
        'Genes Genet Syst',
        'Int Heart J',
        'Intern Med',
        'J Atheroscler Thromb',
        'J Biochem',
        'J Clin Exp Hematop',
        'J Epidemiol',
        'J Gen Appl Microbiol',
        'J Med Invest',
        'J Nippon Med Sch',
        'J Nutr Sci Vitaminol',
        'J Occup Health',
        'J Oleo Sci',
        'J Pharmacobio-dyn',# bpb1978
        'J Reprod Dev',     # jrd
        'J Toxicol Sci',    # jts
        'J Vet Med Sci',    # jvms
        'Jpn Circ J',       # jcj
        'Jpn Heart J',      # jhj
        'Jpn J Infect Dis',
        'Jpn J Med',
        'Jpn J Med Sci Biol',
        'Jpn J Pharmacol',
        'Jpn J Physiol',
        'Kansenshogaku Zasshi',
        'Keio J Med',
        'Kurume Med J',
        'Microbes Environ',
        'Neurol Med Chir (Tokyo)',
        'Nihon Hansenbyo Gakkai Zasshi',
        'Nihon Ishinkin Gakkai Zasshi',
        'Nihon Naibunpi Gakkai Zasshi',
        'Nihon Rinsho Meneki Gakkai Kaishi',
        'Nihon Ronen Igakkai Zasshi',
        'Nihon Shishubyo Gakkai Kaishi',
        'Nippon Ika Daigaku Zasshi',
        'Nippon Jibiinkoka Gakkai Kaiho',
        'Nippon Juigaku Zasshi',
        'Nippon Naika Gakkai Zasshi',
        'Nippon Saikingaku Zasshi',
        'Nippon Yakurigaku Zasshi',
        'Rinsho Ketsueki',
        'Rinsho Shinkeigaku',
        'Sangyo Igaku',
        'Shokuhin Eiseigaku Zasshi',
        'Tohoku J Exp Med',
        'Yakugaku Zasshi',
]
