from __future__ import absolute_import, unicode_literals

# nature journals -- see http://www.nature.com/siteindex/index.html
nature_format = 'http://www.nature.com/{ja}/journal/v{a.volume}/n{a.issue}/pdf/{a.pii}.pdf'
nature_journals = {
    'Am J Gastroenterol': {'ja': 'ajg'},
    'Eur J Clin Nutr': {'ja': 'ejcn'},
    'Eur J Hum Genet': {'ja': 'ejhg'},
    'Eye (Lond)': {'ja': 'eye'},
    'Genes Immun': {'ja': 'gene'},
    'Genet Med': {'ja': 'gim'},
    'Hypertens Res': {'ja': 'hr'},
    'Int J Obes Relat Metab Disord': {'ja': 'ijo'},
    'Int J Obes (Lond)': {'ja': 'ijo'},
    'J Invest Dermatol': {'ja': 'jid'},
    'J Hum Genet': {'ja': 'jhg'},
    'J Hum Hypertens': {'ja': 'jhh'},
    'Kidney Int': {'ja': 'ki'},
    'Leukemia': {'ja': 'leu'},
    'Mod Pathol': {'ja': 'modpathol'},
    'Mol Psychiatry': {'ja': 'mp'},
    'Nature': {'ja': 'nature'},
    'Nat Biotechnol': {'ja': 'nbt'},
    'Nat Cell Biol': {'ja': 'ncb'},
    'Nat Chem': {'ja': 'nchem'},
    'Nat Clin Pract Endocrinol Metab': {'ja': 'nrendo'},
    'Nat Clin Pract Cardiovasc Med': {'ja': 'nrcardio'},
    'Nat Clin Pract Oncol': {'ja': 'nrclinonc'},
    'Nat Clin Pract Gastroenterol Hepatol': {'ja': 'nrgastro'},
    'Nat Clin Pract Urol': {'ja': 'nrurol'},
    'Nat Clin Pract Neurol': {'ja': 'nrneurol'},
    'Nat Clin Pract Nephrol': {'ja': 'nrneph'},
    'Nat Clin Pract Rheumatol': {'ja': 'nrrheum'},
    'Nat Genet': {'ja': 'ng'},
    'Nat Commun': {'ja': 'ncomms'},
    'Nat Nanotechnol': {'ja': 'nnano'},
    'Nat Neurosci': {'ja': 'neuro'},
    'Nat Mater': {'ja': 'nmat'},
    'Nat Med': {'ja': 'nm'},
    'Nat Methods': {'ja': 'nmeth'},
    'Nat Protoc': {'ja': 'nprot'},
    'Nat Rev Drug Discov': {'ja': 'nrd'},
    'Nat Rev Cardiol': {'ja': 'nrcardio'},
    'Nat Rev Clin Oncol': {'ja': 'nrclinonc'},
    'Nat Rev Endocrinol': {'ja': 'nrendo'},
    'Nat Rev Genet': {'ja': 'nrg'},
    'Nat Rev Gastroenterol Hepatol': {'ja': 'nrgastro'},
    'Nat Rev Mol Cell Biol': {'ja': 'nrm'},
    'Nat Rev Nephrol': {'ja': 'nrneph'},
    'Nat Rev Neurol': {'ja': 'nrneurol'},
    'Nat Rev Rheumatol': {'ja': 'nrrheum'},
    'Nat Rev Urol': {'ja': 'nrurol'},
    'Nat Rev Immunol': {'ja': 'nri'},
    'Neuropsychopharmacology': {'ja': 'npp'},
    'Oncogene': {'ja': 'onc'},
    'Pediatr Res': {'ja': 'pr'},
    'Pharmacogenomics J': {'ja': 'tpj'},
}
