from __future__ import absolute_import, unicode_literals

# Science (AAAS) -- requires login "as a courtesy to the community".  Mkay.
aaas_format = 'http://{ja}.sciencemag.org/content/{a.volume}/{a.issue}/{a.first_page}.full.pdf'
aaas_journals = {
    'Science': {'ja': 'www'},
    'Sci Adv': {'ja': 'advances'},
    'Sci Signal': {'ja': 'stke'},
    'Sci Transl Med': {'ja': 'stm'},
}

