from __future__ import absolute_import, unicode_literals

# BIOMED CENTRAL
# 
# Many BMC journals start with "BMC" (they're covered automatically) --
# this list covers the ones that don't.  #TODO: Gather up the ones not in
# here yet.

# the "aid" is the second half of the DOI string (after the slash)
BMC_format = 'http://www.biomedcentral.com/content/pdf/{aid}.pdf'

BMC_journals = (
    'Diagn Pathol',
    'Genome Biol',
    'Genome Med',
    'Hum Genomics',
    'J Clin Bioinforma',
    'J Transl Med',
)
